@@ -224,7 +224,7 @@ def sync_endpoint(client, #pylint: disable=too-many-branches
 
             session_id = 'initial'
             if pagination:
-                params['page_size'] = limit
+                params['limit'] = limit
 
             while offset <= total_records and session_id is not None:
                 if pagination and page != 0:
